/* ---------------------------------------------------------------------
 * multilingual.c
 * 
 * =====================================================================
 * C subprograms for FreeBASIC
 * ---------------------------
 * 
 * - fbsetlocale      - set program locale
 * - fbbindtextdomain - specify directory for domain
 * - fbtextdomain     - set default domain
 * - settextdomain    - set translation domain for GtkBuilder all-in-one 
 * - fbgettext        - translate a text 
 * 
 * =====================================================================
 * 
 * compile with: 
 * ------------
 *   
 *    gcc -Wall -c -pedantic multilingual.c  
 * 
 * create the static library with
 * ------------------------------
 * 
 *    ar rcs libmultilingual.a multilingual.o 
 * 
 *
 * C. 2011 Klaus Siebke, www.siebke.com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA 02110-1301, USA.
 * ---------------------------------------------------------------------
 */
#include <libintl.h>
#include <locale.h>
#include <stdio.h>

void fbsetlocale(char *lcall)
{
  setlocale(LC_ALL, lcall);
}

char * fbbindtextdomain(char *domname, char *dompath)
{
   return bindtextdomain(domname, dompath); 
}

char * fbbindtextdomaincodeset(char *domname, char *codeset)
{
   return bind_textdomain_codeset(domname, codeset); 
}


char * fbtextdomain(char *domname)
{
   return textdomain(domname); 
}

void settextdomain(char *domname, char *dompath)
{
  /* combined function - for ease of use */
  setlocale(LC_ALL, ""); 
  bindtextdomain(domname, dompath);
  textdomain(domname);
}

char * fbgettext(char *tobetranslated)
{
   return gettext(tobetranslated); 
}
